svg_path/trig
Trigonometry helpers for SVG-facing degree angles.
Values
pub fn cos_degrees(degrees: Float) -> Float
Return the cosine of an angle in degrees.
Non-finite inputs propagate through the platform trigonometric function instead of causing angle normalization to panic.
pub fn degrees_to_radians(degrees: Float) -> Float
Convert degrees to radians.
pub fn radians_to_degrees(radians: Float) -> Float
Convert radians to degrees.
pub fn sin_degrees(degrees: Float) -> Float
Return the sine of an angle in degrees.
Non-finite inputs propagate through the platform trigonometric function instead of causing angle normalization to panic.
pub fn tan_degrees(degrees: Float) -> Float
Return the tangent of an angle in degrees.
Non-finite inputs propagate through the platform trigonometric function instead of causing angle normalization to panic.